@@ -30,7 +30,7 @@ class _FlexibleSubscribe(UserMixin):
       params['autoSubscribe'] = auto_subscribe
     query = self.signed_query(params)
     r = await self.client.post(
-      f'{self.base}/sapi/v1/simple-earn/flexible/subscribe?{query}',
+      f'/sapi/v1/simple-earn/flexible/subscribe?{query}',
       headers={'X-MBX-APIKEY': self.api_key},
     )
     return validate_response(r.text, FlexibleSubscribeResponse)
