@@ -22,6 +22,6 @@ class _RecentTrades(ClientMixin):
   @ClientMixin.with_client
   async def recent_trades(self, symbol: str, *, limit: int = 500) -> list[Trade]:
     """https://developers.binance.com/docs/binance-spot-api-docs/rest-api/market-data-endpoints#recent-trades-list"""
-    r = await self.client.get(f'{self.base}/api/v3/trades', params={'symbol': symbol, 'limit': limit})
+    r = await self.client.get(f'/api/v3/trades', params={'symbol': symbol, 'limit': limit})
     return validate_response(r.text, TradeResponse).root
   
\ No newline at end of file
