@@ -18,7 +18,7 @@ class Wallet(UserMixin):
       'timestamp': timestamp.now(),
     })
     r = await self.client.post(
-      f'{self.base}/sapi/v1/capital/withdraw/apply?{query}',
+      f'/sapi/v1/capital/withdraw/apply?{query}',
       headers={'X-MBX-APIKEY': self.api_key},
     )
     return validate_response(r.text, WithdrawResponse)
\ No newline at end of file
